% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ISAnalytics-package.R
\docType{package}
\name{ISAnalytics}
\alias{ISAnalytics}
\title{ISAnalytics: Analyze gene therapy vector insertion sites data
identified from genomics next generation sequencing reads for
clonal tracking studies}
\description{
\lifecycle{maturing}
In gene therapy, stem cells are modified using viral
vectors to deliver the therapeutic transgene and replace functional
properties since the genetic modification is stable and inherited in
all cell progeny. The retrieval and mapping of the sequences flanking
the virus-host DNA junctions allows the identification of insertion
sites (IS), essential for monitoring the evolution of genetically
modified cells in vivo. A comprehensive toolkit for the analysis of
IS is required to foster clonal trackign studies and supporting the
assessment of safety and long term efficacy in vivo. This package
is aimed at (1) supporting automation of IS workflow, (2) performing
base and advance analysis for IS tracking (clonal abundance, clonal
expansions and statistics for insertional mutagenesis, etc.),
(3) providing basic biology insights of transduced stem cells in vivo.
}
\section{Useful resources}{

\itemize{
\item \href{https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5702242/}{VISPA2:
A Scalable Pipeline for High-Throughput Identification
and Annotation of Vector Integration Sites}
}
}

\section{ISAnalytics function families}{

\itemize{
\item Import functions:
\itemize{
\item \code{\link{import_single_Vispa2Matrix}}
\item \code{\link{import_association_file}}
\item \code{\link{import_parallel_Vispa2Matrices_interactive}}
\item \code{\link{import_parallel_Vispa2Matrices_auto}}
}
\item Aggregation functions:
\itemize{
\item \code{\link{aggregate_metadata}}
\item \code{\link{aggregate_values_by_key}}
}
\item Collision removal functions:
\itemize{
\item \code{\link{remove_collisions}}
\item \code{\link{realign_after_collisions}}
}
\item Removal of outliers from raw reads
\itemize{
\item \code{\link{outlier_filter}}
\item \code{\link{outliers_by_pool_fragments}}
}
\item Recalibration functions:
\itemize{
\item \code{\link{compute_near_integrations}}
}
\item Analysis functions:
\itemize{
\item \code{\link{compute_abundance}}
\item \code{\link{comparison_matrix}}
\item \code{\link{separate_quant_matrices}}
\item \code{\link{threshold_filter}}
\item \code{\link{top_integrations}}
\item \code{\link{sample_statistics}}
\item \code{\link{CIS_grubbs}}
\item \code{\link{cumulative_count_union}}
}
\item Plotting functions:
\itemize{
\item \code{\link{CIS_volcano_plot}}
}
\item Utility functions:
\itemize{
\item \code{\link{generate_blank_association_file}}
\item \code{\link{generate_Vispa2_launch_AF}}
\item \code{\link{unzip_file_system}}
\item \code{\link{as_sparse_matrix}}
}
}
}

\section{Vignettes}{

\itemize{
\item \code{vignette("How to use import functions", package = "ISAnalytics")}
\item \code{vignette("Collision removal functionality",
package = "ISAnalytics")}
\item \code{vignette("Working with aggregate functions",
package = "ISAnalytics")}
}
}

